aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/com/elisis/gtnhlanth/loader/RecipeLoader.java
diff options
context:
space:
mode:
authorNxer <306803661@qq.com>2023-09-29 11:04:21 +0800
committerNxer <306803661@qq.com>2023-09-29 11:04:21 +0800
commitdabea51b0ec119294ac153988df3af6c79df9cb9 (patch)
treee48b80027a703ed15a98c6ec14908f805fe7c8ae /src/main/java/com/elisis/gtnhlanth/loader/RecipeLoader.java
parente06dea6c337f181ed86065fa6214fa9ab5e79793 (diff)
downloadGT5-Unofficial-dabea51b0ec119294ac153988df3af6c79df9cb9.tar.gz
GT5-Unofficial-dabea51b0ec119294ac153988df3af6c79df9cb9.tar.bz2
GT5-Unofficial-dabea51b0ec119294ac153988df3af6c79df9cb9.zip
Adjust value ; replace Lepersonnite with DephosphatedSamariumConcentrate
Diffstat (limited to 'src/main/java/com/elisis/gtnhlanth/loader/RecipeLoader.java')
-rw-r--r--src/main/java/com/elisis/gtnhlanth/loader/RecipeLoader.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/main/java/com/elisis/gtnhlanth/loader/RecipeLoader.java b/src/main/java/com/elisis/gtnhlanth/loader/RecipeLoader.java
index ae3212540a..5c6e1bb621 100644
--- a/src/main/java/com/elisis/gtnhlanth/loader/RecipeLoader.java
+++ b/src/main/java/com/elisis/gtnhlanth/loader/RecipeLoader.java
@@ -35,7 +35,6 @@ import goodgenerator.items.MyMaterial;
import gregtech.api.enums.GT_Values;
import gregtech.api.enums.ItemList;
import gregtech.api.enums.Materials;
-import gregtech.api.enums.Mods;
import gregtech.api.enums.OrePrefixes;
import gregtech.api.util.GTPP_Recipe;
import gregtech.api.util.GT_Log;
@@ -2129,14 +2128,15 @@ public class RecipeLoader {
// 2B DilutedSamariumRareEarthSolution + 3B Oxalate
// =EV@10s=
// 5 ImpureSamariumOxalate + 0.1*2 LepersonniteDust + 50L MuddySamariumRareEarthSolution
GT_Values.RA.stdBuilder().itemInputs(GT_Utility.getIntegratedCircuit(13))
.fluidInputs(
DilutedSamariumRareEarthSolution.getFluidOrGas(2000),
MyMaterial.oxalate.getFluidOrGas(3000))
.itemOutputs(
ImpureSamariumOxalate.get(OrePrefixes.dust, 5),
- GT_ModHandler.getModItem(Mods.GTPlusPlus.ID, "itemDustLepersonnite", 1))
+ DephosphatedSamariumConcentrate.get(OrePrefixes.dust, 3))
.fluidOutputs(MuddySamariumRareEarthSolution.getFluidOrGas(50)).outputChances(10000, 1000).eut(1920)
.duration(200).addTo(GT_Recipe.GT_Recipe_Map.sMultiblockChemicalRecipes);
@@ -2129,14 +2128,15 @@ public class RecipeLoader {
// 2B DilutedSamariumRareEarthSolution + 3B Oxalate
// =EV@10s=
- // 5 ImpureSamariumOxalate + 0.1*2 LepersonniteDust + 50L MuddySamariumRareEarthSolution
+ // 5 ImpureSamariumOxalate + 50L MuddySamariumRareEarthSolution + 0.1*2 LepersonniteDust
+ // LepersonniteDust -> DephosphatedSamariumConcentrate
GT_Values.RA.stdBuilder().itemInputs(GT_Utility.getIntegratedCircuit(13))
.fluidInputs(